# Radio Paradise player and notifier

## usage

Launch the program in command line with

```$ paradise_player```

or the shortcut

```$ rpp```

it will start to play the steam and send notification when song changes.


Ctrl+C to stop it

## installation

```pip install paradise_player```

or clone the repository at XXXXX
and run

```python setup.py install```

## configuration

config file is stored in ~/.config/paradise_player/config.cfg

see file config_sample.cfg for all configuration parameters.

## credits

Inspired by https://github.com/jmdh/rpnotify/blob/master/rpnotify
